symmetrize — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# symmetrize

Procar.symmetrize(symprec: float = 1e-05, outcar: str | None = None, structure=None, spglib: bool = True)

  A method that will symmetrize the kpoints, projections, and bands of the calculation

  Parameters:

    - symprec (float, optional) – The symmetry precision, by default 1e-5

    - outcar (str, optional) – The OUTCAR filename, by default None

    - structure (pyprocar.core.Structure, optional) – The structure of the calculation, by default None

    - spglib (bool, optional) – Boolean value to use spglib for the symmetrization, by default True